import { amountItem, chainItem, circleDomainItem, circleNonceItem, payloadIdItem, sequenceItem, universalAddressItem, } from "../layout-items";
import { registerPayloadTypes } from "../vaa";
const encodedExecutionInfoItem = {
    binary: "object",
    layout: [
        { name: "size", binary: "uint", size: 4, custom: 3 * 32, omit: true },
        { name: "waste", binary: "uint", size: 31, custom: 0n, omit: true },
        { name: "version", binary: "uint", size: 1, custom: 0, omit: true },
        { name: "gasLimit", ...amountItem },
        { name: "targetChainRefundPerGasUnused", ...amountItem },
    ],
};
const addressChainItem = {
    binary: "object",
    layout: [
        { name: "chain", ...chainItem() },
        { name: "address", ...universalAddressItem },
    ],
};
const vaaKeyLayout = [
    { name: "chain", ...chainItem() },
    { name: "emitterAddress", ...universalAddressItem },
    { name: "sequence", ...sequenceItem },
];
const cctpKeyLayout = [
    { name: "size", binary: "uint", size: 4, custom: 12, omit: true },
    { name: "domain", ...circleDomainItem },
    { name: "nonce", ...circleNonceItem },
];
const messageKeySwitchLayout = {
    binary: "switch",
    idSize: 1,
    idTag: "keyType",
    layouts: [
        [[1, "VAA"], vaaKeyLayout],
        [[2, "CCTP"], cctpKeyLayout],
    ],
};
const namedPayloads = [
    [
        "DeliveryInstruction",
        [
            payloadIdItem(1),
            { name: "target", ...addressChainItem },
            { name: "payload", binary: "bytes", lengthSize: 4 },
            { name: "requestedReceiverValue", ...amountItem },
            { name: "extraReceiverValue", ...amountItem },
            { name: "executionInfo", ...encodedExecutionInfoItem },
            { name: "refund", ...addressChainItem },
            { name: "refundDeliveryProvider", ...universalAddressItem },
            { name: "sourceDeliveryProvider", ...universalAddressItem },
            { name: "senderAddress", ...universalAddressItem },
            { name: "messageKeys", binary: "array", lengthSize: 1, layout: messageKeySwitchLayout },
        ],
    ],
    [
        "RedeliveryInstruction",
        [
            payloadIdItem(2),
            { name: "deliveryVaaKey", binary: "object", layout: vaaKeyLayout },
            { name: "targetChain", ...chainItem() },
            { name: "newRequestedReceiverValue", ...amountItem },
            { name: "newEncodedExecutionInfo", ...encodedExecutionInfoItem },
            { name: "newSourceDeliveryProvider", ...universalAddressItem },
            { name: "newSenderAddress", ...universalAddressItem },
        ],
    ],
];
registerPayloadTypes("Relayer", namedPayloads);
//# sourceMappingURL=relayer.js.map